﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using Telerik.Windows.Documents.Spreadsheet.FormatProviders.OpenXml.Xlsx;
using Telerik.Windows.Documents.Spreadsheet.Model.Printing;
using System.IO;
using Telerik.Windows.Documents.Model;
using Telerik.Windows.Documents.Spreadsheet.Model;
using System.Drawing;

public partial class RadGridExportXLSXFilteringOnExportedTable : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
    }
    protected void RadGrid1_NeedDataSource(object sender, GridNeedDataSourceEventArgs e)
    {
        RadGrid1.DataSource = GetGridSource();
    }
    private DataTable GetGridSource()
    {
        DataTable dataTable = new DataTable();

        DataColumn column = new DataColumn();
        column.DataType = Type.GetType("System.Int32");
        column.ColumnName = "OrderID";
        dataTable.Columns.Add(column);

        column = new DataColumn();
        column.DataType = Type.GetType("System.DateTime");
        column.ColumnName = "OrderDate";
        dataTable.Columns.Add(column);

        column = new DataColumn();
        column.DataType = Type.GetType("System.Decimal");
        column.ColumnName = "Freight";
        dataTable.Columns.Add(column);

        column = new DataColumn();
        column.DataType = Type.GetType("System.String");
        column.ColumnName = "ShipName";
        dataTable.Columns.Add(column);

        column = new DataColumn();
        column.DataType = Type.GetType("System.String");
        column.ColumnName = "ShipCountry";
        dataTable.Columns.Add(column);

        DataColumn[] PrimaryKeyColumns = new DataColumn[1];
        PrimaryKeyColumns[0] = dataTable.Columns["OrderID"];
        dataTable.PrimaryKey = PrimaryKeyColumns;

        for (int i = 0; i <= 80; i++)
        {
            DataRow row = dataTable.NewRow();
            row["OrderID"] = i + 1;
            row["OrderDate"] = DateTime.Now;
            row["Freight"] = (i + 1) + (i + 1) * 0.1 + (i + 1) * 0.01;
            row["ShipName"] = "This is quite the long text " + (i + 1);
            row["ShipCountry"] = "Country " + (i + 1);

            dataTable.Rows.Add(row);
        }

        return dataTable;
    }
    protected void RadGrid1_GridExporting(object sender, GridExportingArgs e)
    {
        if ((e.ExportType == ExportType.ExcelXlsx))
        {
            // generating the worksheet
            XlsxFormatProvider xlsxProvider = new XlsxFormatProvider();
            Workbook workBook = xlsxProvider.Import(Encoding.Default.GetBytes(e.ExportOutput));
            WorksheetPageSetup pageSetup = workBook.ActiveWorksheet.WorksheetPageSetup;
            workBook.ActiveWorksheet.Rows.Insert(0);

            // adding header 
            var cols = RadGrid1.MasterTableView.Columns.Count - 1;
            CellIndex A1Cell = new CellIndex(0, 0);
            CellIndex lastCellOnRow = new CellIndex(0, cols);
            CellSelection headerCell = workBook.ActiveWorksheet.Cells[A1Cell, lastCellOnRow];
            headerCell.MergeAcross();
            headerCell.SetValue("Sample Header Text");
            headerCell.SetHorizontalAlignment(RadHorizontalAlignment.Center);

            // adding footer
            var rows = RadGrid1.MasterTableView.Items.Count + 4;
            workBook.ActiveWorksheet.Rows.Insert(rows);
            CellIndex lastRowCell = new CellIndex(rows, 0);
            CellIndex lastRowlastCell = new CellIndex(rows, cols);
            CellSelection footerCell = workBook.ActiveWorksheet.Cells[lastRowCell, lastRowlastCell];
            footerCell.MergeAcross();
            footerCell.SetValue("Sample Footer Text");
            footerCell.SetHorizontalAlignment(RadHorizontalAlignment.Center);

            // general settings
            pageSetup.PaperType = PaperTypes.A4;
            pageSetup.PageOrientation = PageOrientation.Landscape;
            pageSetup.CenterHorizontally = true;
            workBook.Sheets.Add(SheetType.Worksheet).Name = "NewSheet";
            workBook.ActiveWorksheet.Filter.FilterRange = new CellRange(1, 0, 1, 4);

            byte[] data = null;

            using (MemoryStream ms = new MemoryStream())
            {
                xlsxProvider.Export(workBook, ms);
                data = ms.ToArray();
            }

            Response.ContentType = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet";
            Response.Headers.Remove("Content-Disposition");
            Response.AppendHeader("Content-Disposition", "attachment; filename=" + RadGrid1.ExportSettings.FileName + ".xlsx");
            Response.BinaryWrite(data);
            Response.End();
        }
    }

    protected void RadGrid1_PreRender(object sender, EventArgs e)
    {
        if (RadGrid1.IsExporting)
        {
            Font font = new Font("Helvetica Neue", 16.0F);
            System.Drawing.Image fakeImage = new Bitmap(1, 1);
            Graphics graphics = Graphics.FromImage(fakeImage);

            foreach (GridColumn col in RadGrid1.MasterTableView.RenderColumns)
            {
                int minWidth = 50;
                foreach (GridDataItem item in RadGrid1.Items)
                {
                    TableCell cell = item[col.UniqueName];
                    int width = (int)graphics.MeasureString(cell.Text, font).Width;

                    if (width > minWidth)
                    {
                        col.HeaderStyle.Width = width;
                    }
                }
            }
        }
    }
}